package com.supervision.police.controller;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.police.dto.user.*;
import com.supervision.police.service.SystemUserService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

@Tag(name = "用户管理")
@RestController
@RequestMapping("/user")
@RequiredArgsConstructor
public class UserController {

    private final SystemUserService userService;


    @Operation(summary = "登录")
    @PostMapping("/login")
    public LoginResVO login(@RequestBody LoginReqVO reqVO) {

        return userService.login(reqVO);
    }


    @Operation(summary = "新增用户信息")
    @PostMapping("/saveUserInfo")
    public String saveUserInfo(@RequestBody UserInfoReqVo userInfoReqVo) {

        return userService.saveUserInfo(userInfoReqVo);
    }

    @Operation(summary = "修改用户信息")
    @PostMapping("/update")
    public void updateUser(@RequestBody UserInfoReqVo userInfoReqVo) {
        userService.updateUserInfo(userInfoReqVo);
    }

    @Operation(summary = "修改用户状态")
    @PostMapping("/updateUserStatus")
    public void updateUserStatus(@RequestBody UserStatusReqVo userStatusReqVo) {
        userService.updateUserStatus(userStatusReqVo);
    }

    @Operation(summary = "删除用户信息")
    @DeleteMapping("/delete")
    public Boolean deleteUser(@Parameter(name = "id") @RequestParam(name="id") String id) {
        return userService.deleteUser(id);
    }
    @Operation(summary = "查看用户信息列表")
    @GetMapping("/list")
    public IPage<UserInfoDTO> list(@Parameter(name = "userName",description = "用户名") @RequestParam(required = false) String userName,
                                   @Parameter(name = "roleId",description = "角色id") @RequestParam(required = false) String roleId,
                                   @Parameter(name = "roleName",description = "角色名") @RequestParam(required = false) String roleName,
                                   @Parameter(name = "pageNum",description = "页码") @RequestParam(defaultValue = "1") Integer pageNum,
                                   @Parameter(name = "pageSize",description = "每页大小") @RequestParam(defaultValue = "10") Integer pageSize) {
        return userService.list(userName, roleId, roleName, pageNum, pageSize);
    }





}
